bayespy.inference.vmp.nodes.gamma.GammaMoments.compute_fixed_moments
====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gamma

.. automethod:: GammaMoments.compute_fixed_moments